<?php

namespace Lavalite\Auto\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Lavalite\Auto\Interfaces\AutomodelRepositoryInterface;

class AutomodelPublicController extends BaseController
{
    // use AutomodelWorkflow;

    /**
     * Constructor.
     *
     * @param type \Lavalite\Automodel\Interfaces\AutomodelRepositoryInterface $automodel
     *
     * @return type
     */
    public function __construct(AutomodelRepositoryInterface $automodel)
    {
        $this->repository = $automodel;
        parent::__construct();
    }

    /**
     * Show automodel's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $automodels = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$auto::$automodel.names'))
            ->view('$auto::public.automodel.index')
            ->data(compact('$automodels'))
            ->output();
    }

    /**
     * Show automodel's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $automodels = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$auto::$automodel.names'))
            ->view('$auto::public.automodel.index')
            ->data(compact('$automodels'))
            ->output();
    }

    /**
     * Show automodel.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $automodel = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$automodel->name . trans('$auto::$automodel.name'))
            ->view('$auto::public.automodel.show')
            ->data(compact('$automodel'))
            ->output();
    }

}
