<?php

namespace Lavalite\Auto\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Lavalite\Auto\Interfaces\BodyRepositoryInterface;

class BodyPublicController extends BaseController
{
    // use BodyWorkflow;

    /**
     * Constructor.
     *
     * @param type \Lavalite\Body\Interfaces\BodyRepositoryInterface $body
     *
     * @return type
     */
    public function __construct(BodyRepositoryInterface $body)
    {
        $this->repository = $body;
        parent::__construct();
    }

    /**
     * Show body's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $bodies = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$auto::$body.names'))
            ->view('$auto::public.body.index')
            ->data(compact('$bodies'))
            ->output();
    }

    /**
     * Show body's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $bodies = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$auto::$body.names'))
            ->view('$auto::public.body.index')
            ->data(compact('$bodies'))
            ->output();
    }

    /**
     * Show body.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $body = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$body->name . trans('$auto::$body.name'))
            ->view('$auto::public.body.show')
            ->data(compact('$body'))
            ->output();
    }

}
