<?php

namespace Lavalite\Auto\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Lavalite\Auto\Interfaces\CarRepositoryInterface;

class CarPublicController extends BaseController
{
    // use CarWorkflow;

    /**
     * Constructor.
     *
     * @param type \Lavalite\Car\Interfaces\CarRepositoryInterface $car
     *
     * @return type
     */
    public function __construct(CarRepositoryInterface $car)
    {
        $this->repository = $car;
        parent::__construct();
    }

    /**
     * Show car's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $cars = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$auto::$car.names'))
            ->view('$auto::public.car.index')
            ->data(compact('$cars'))
            ->output();
    }

    /**
     * Show car's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $cars = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$auto::$car.names'))
            ->view('$auto::public.car.index')
            ->data(compact('$cars'))
            ->output();
    }

    /**
     * Show car.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $car = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$car->name . trans('$auto::$car.name'))
            ->view('$auto::public.car.show')
            ->data(compact('$car'))
            ->output();
    }

}
