<?php

namespace Lavalite\Auto\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lavalite\Auto\Models\Automodel;

class AutomodelPolicy
{

    /**
     * Determine if the given user can view the automodel.
     *
     * @param UserPolicy $user
     * @param Automodel $automodel
     *
     * @return bool
     */
    public function view(UserPolicy $user, Automodel $automodel)
    {
        if ($user->canDo('auto.automodel.view') && $user->isAdmin()) {
            return true;
        }

        return $automodel->user_id == user_id() && $automodel->user_type == user_type();
    }

    /**
     * Determine if the given user can create a automodel.
     *
     * @param UserPolicy $user
     * @param Automodel $automodel
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('auto.automodel.create');
    }

    /**
     * Determine if the given user can update the given automodel.
     *
     * @param UserPolicy $user
     * @param Automodel $automodel
     *
     * @return bool
     */
    public function update(UserPolicy $user, Automodel $automodel)
    {
        if ($user->canDo('auto.automodel.edit') && $user->isAdmin()) {
            return true;
        }

        return $automodel->user_id == user_id() && $automodel->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given automodel.
     *
     * @param UserPolicy $user
     * @param Automodel $automodel
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Automodel $automodel)
    {
        return $automodel->user_id == user_id() && $automodel->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given automodel.
     *
     * @param UserPolicy $user
     * @param Automodel $automodel
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Automodel $automodel)
    {
        if ($user->canDo('auto.automodel.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given automodel.
     *
     * @param UserPolicy $user
     * @param Automodel $automodel
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Automodel $automodel)
    {
        if ($user->canDo('auto.automodel.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
