<?php

namespace Lavalite\Auto\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lavalite\Auto\Models\Body;

class BodyPolicy
{

    /**
     * Determine if the given user can view the body.
     *
     * @param UserPolicy $user
     * @param Body $body
     *
     * @return bool
     */
    public function view(UserPolicy $user, Body $body)
    {
        if ($user->canDo('auto.body.view') && $user->isAdmin()) {
            return true;
        }

        return $body->user_id == user_id() && $body->user_type == user_type();
    }

    /**
     * Determine if the given user can create a body.
     *
     * @param UserPolicy $user
     * @param Body $body
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('auto.body.create');
    }

    /**
     * Determine if the given user can update the given body.
     *
     * @param UserPolicy $user
     * @param Body $body
     *
     * @return bool
     */
    public function update(UserPolicy $user, Body $body)
    {
        if ($user->canDo('auto.body.edit') && $user->isAdmin()) {
            return true;
        }

        return $body->user_id == user_id() && $body->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given body.
     *
     * @param UserPolicy $user
     * @param Body $body
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Body $body)
    {
        return $body->user_id == user_id() && $body->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given body.
     *
     * @param UserPolicy $user
     * @param Body $body
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Body $body)
    {
        if ($user->canDo('auto.body.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given body.
     *
     * @param UserPolicy $user
     * @param Body $body
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Body $body)
    {
        if ($user->canDo('auto.body.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
