<?php

namespace Lavalite\Auto\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lavalite\Auto\Models\Car;

class CarPolicy
{

    /**
     * Determine if the given user can view the car.
     *
     * @param UserPolicy $user
     * @param Car $car
     *
     * @return bool
     */
    public function view(UserPolicy $user, Car $car)
    {
        if ($user->canDo('auto.car.view') && $user->isAdmin()) {
            return true;
        }

        return $car->user_id == user_id() && $car->user_type == user_type();
    }

    /**
     * Determine if the given user can create a car.
     *
     * @param UserPolicy $user
     * @param Car $car
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('auto.car.create');
    }

    /**
     * Determine if the given user can update the given car.
     *
     * @param UserPolicy $user
     * @param Car $car
     *
     * @return bool
     */
    public function update(UserPolicy $user, Car $car)
    {
        if ($user->canDo('auto.car.edit') && $user->isAdmin()) {
            return true;
        }

        return $car->user_id == user_id() && $car->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given car.
     *
     * @param UserPolicy $user
     * @param Car $car
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Car $car)
    {
        return $car->user_id == user_id() && $car->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given car.
     *
     * @param UserPolicy $user
     * @param Car $car
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Car $car)
    {
        if ($user->canDo('auto.car.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given car.
     *
     * @param UserPolicy $user
     * @param Car $car
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Car $car)
    {
        if ($user->canDo('auto.car.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
