<?php

namespace Lavalite\Auto\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Lavalite\Auto\Models\Auto;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Lavalite\Auto\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/auto/manufacturer/*')) {
            Route::bind('manufacturer', function ($manufacturer) {
                $manufacturerrepo = $this->app->make('Lavalite\Auto\Interfaces\ManufacturerRepositoryInterface');
                return $manufacturerrepo->findorNew($manufacturer);
            });
        }
        if (Request::is('*/auto/car/*')) {
            Route::bind('car', function ($car) {
                $carrepo = $this->app->make('Lavalite\Auto\Interfaces\CarRepositoryInterface');
                return $carrepo->findorNew($car);
            });
        }
        if (Request::is('*/auto/automodel/*')) {
            Route::bind('automodel', function ($automodel) {
                $automodelrepo = $this->app->make('Lavalite\Auto\Interfaces\AutomodelRepositoryInterface');
                return $automodelrepo->findorNew($automodel);
            });
        }
        if (Request::is('*/auto/body/*')) {
            Route::bind('body', function ($body) {
                $bodyrepo = $this->app->make('Lavalite\Auto\Interfaces\BodyRepositoryInterface');
                return $bodyrepo->findorNew($body);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
